pub fn check_share(share: &NormalizedShare) -> IntegrityResultExpand description
Check the integrity of a normalized share. Returns Valid if all
checks pass, or Invalid with a list of issues.
pub fn check_share(share: &NormalizedShare) -> IntegrityResultCheck the integrity of a normalized share. Returns Valid if all
checks pass, or Invalid with a list of issues.